LoggingAPIHandler

Struct LoggingAPIHandler 

pub struct LoggingAPIHandler { /* private fields */ }
An API handler for updating log filtering directives at runtime.

This handler exposes two main routes – /logging/override and /logging/reset – which allow for overriding the default log filtering directives (configured at startup) at runtime, and then resetting them once the override is no longer needed.

As this has the potential for incredibly verbose logging at runtime, the override is set with a specific duration in which it will apply. Once an override has been active for the configured duration, it will automatically be reset unless the override is refreshed before the duration elapses.

The maximum duration for an override is 10 minutes.