pub struct LoggingOverrideWorker { /* private fields */ }Expand description
A worker that processes log filter directive overrides.
When running, the worker asserts a set of routes (based on LoggingAPIHandler) that allow triggering
an override of the current logging filter directives as well as clearing (resetting) the active override.